
From: Patrick Boettcher <pb@linuxtv.org>

Add dvb_pll_desc for ALPS TDED4 used in Nebula USB boxes.  Changed the
name-field of the FMD1216.

Signed-off-by: Patrick Boettcher <pb@linuxtv.org>
Signed-off-by: Johannes Stezenbach <js@linuxtv.org>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 drivers/media/dvb/frontends/dvb-pll.c |   26 +++++++++++++++++++++++++-
 drivers/media/dvb/frontends/dvb-pll.h |    1 +
 2 files changed, 26 insertions(+), 1 deletion(-)

diff -puN drivers/media/dvb/frontends/dvb-pll.c~dvb-frontend-add-alps-tded4-pll drivers/media/dvb/frontends/dvb-pll.c
--- 25/drivers/media/dvb/frontends/dvb-pll.c~dvb-frontend-add-alps-tded4-pll	Mon Jun 27 15:37:05 2005
+++ 25-akpm/drivers/media/dvb/frontends/dvb-pll.c	Mon Jun 27 15:37:05 2005
@@ -208,7 +208,7 @@ static void fmd1216me_bw(u8 *buf, u32 fr
 }
 
 struct dvb_pll_desc dvb_pll_fmd1216me = {
-	.name = "placeholder",
+	.name = "Philips FMD1216ME",
 	.min = 50870000,
 	.max = 858000000,
 	.setbw = fmd1216me_bw,
@@ -225,6 +225,30 @@ struct dvb_pll_desc dvb_pll_fmd1216me = 
 };
 EXPORT_SYMBOL(dvb_pll_fmd1216me);
 
+/* ALPS TDED4
+ * used in Nebula-Cards and USB boxes
+ */
+static void tded4_bw(u8 *buf, u32 freq, int bandwidth)
+{
+	if (bandwidth == BANDWIDTH_8_MHZ)
+		buf[3] |= 0x04;
+}
+
+struct dvb_pll_desc dvb_pll_tded4 = {
+	.name = "ALPS TDED4",
+	.min = 47000000,
+	.max = 863000000,
+	.setbw = tded4_bw,
+	.count = 4,
+	.entries = {
+		{ 153000000, 36166667, 166667, 0x85, 0x01 },
+		{ 470000000, 36166667, 166667, 0x85, 0x02 },
+		{ 823000000, 36166667, 166667, 0x85, 0x08 },
+		{ 999999999, 36166667, 166667, 0x85, 0x88 },
+	}
+};
+EXPORT_SYMBOL(dvb_pll_tded4);
+
 /* ----------------------------------------------------------- */
 /* code                                                        */
 
diff -puN drivers/media/dvb/frontends/dvb-pll.h~dvb-frontend-add-alps-tded4-pll drivers/media/dvb/frontends/dvb-pll.h
--- 25/drivers/media/dvb/frontends/dvb-pll.h~dvb-frontend-add-alps-tded4-pll	Mon Jun 27 15:37:05 2005
+++ 25-akpm/drivers/media/dvb/frontends/dvb-pll.h	Mon Jun 27 15:37:05 2005
@@ -31,6 +31,7 @@ extern struct dvb_pll_desc dvb_pll_env57
 extern struct dvb_pll_desc dvb_pll_tua6034;
 extern struct dvb_pll_desc dvb_pll_tda665x;
 extern struct dvb_pll_desc dvb_pll_fmd1216me;
+extern struct dvb_pll_desc dvb_pll_tded4;
 
 int dvb_pll_configure(struct dvb_pll_desc *desc, u8 *buf,
 		      u32 freq, int bandwidth);
_
